@@ -17,7 +17,8 @@ def api(token_):
         print("Token successfully authenticated")
         return response
     else:
-        raise ValueError("API token not valid")
+        raise ValueError(response.text)
+    # "API token not valid"
 
 
 def getToken():
